@@ -1543,9 +1543,4 @@ test_with_dir("progress(), running(), and failed()", {
   expect_warning(prg <- progress(), regexp = "deprecated")
   expect_warning(run <- running(), regexp = "deprecated")
   expect_warning(fld <- failed(), regexp = "deprecated")
-  expect_true(is.data.frame(prg))
-  expect_equal(prg$target, "x")
-  expect_equal(prg$progress, "failed")
-  expect_equal(run, character(0))
-  expect_equal(fld, "x")
 })
